@@ -18,7 +18,7 @@ async fn lair_integration_test() {
     let tmpdir = tempfile::tempdir().unwrap();
     std::env::set_var("LAIR_DIR", tmpdir.path());
 
-    lair_keystore::execute_lair().await.unwrap();
+    lair_keystore::execute_lair(false).await.unwrap();
 
     let passphrase = sodoken::BufRead::new_no_lock(b"passphrase");
     let config = lair_keystore_api::Config::builder()
